@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Roles::List;
 
 BEGIN {
-    $WWW::Google::Contacts::Roles::List::VERSION = '0.26';
+    $WWW::Google::Contacts::Roles::List::VERSION = '0.27';
 }
 
 use Moose::Role;
@@ -103,9 +103,9 @@ sub _build_elements {
     my $data    = WWW::Google::Contacts::Data->decode_xml($content);
     my $array   = $data->{entry} || [];
 
-    #use Data::Dumper;
-    #print Dumper $array->[0];
-    #die;
+    if ( ref($array) eq 'HASH' ) {
+        $array = [$array];
+    }
 
 # ..lots of overhead to bless them all now.
 #my $class = $self->element_class;
